[Xfce4-commits] [apps/xfce4-terminal] 01/01: Fix uninitialized value usage

noreply at xfce.org noreply at xfce.org
Mon Jun 6 22:09:15 CEST 2016


This is an automated email from the git hooks/post-receive script.

ochosi pushed a commit to branch master
in repository apps/xfce4-terminal.

commit 9a094bbda00a94e06a5ebcc699c7b1ebb27fcf92
Author: Igor <f2404 at yandex.ru>
Date:   Mon Jun 6 22:09:02 2016 +0200

    Fix uninitialized value usage
---
 terminal/terminal-window.c | 7 ++++++-
 1 file changed, 6 insertions(+), 1 deletion(-)

diff --git a/terminal/terminal-window.c b/terminal/terminal-window.c
index cd9788d..1ca9660 100644
--- a/terminal/terminal-window.c
+++ b/terminal/terminal-window.c
@@ -1066,7 +1066,12 @@ terminal_window_notebook_drag_data_received (GtkWidget        *widget,
       notebook = gtk_drag_get_source_widget (context);
       terminal_return_if_fail (GTK_IS_NOTEBOOK (notebook));
 
-      /* leave if there is only one
+      /* get the dragged screen */
+      screen = (GtkWidget **) gtk_selection_data_get_data (selection_data);
+      if (!TERMINAL_IS_SCREEN (*screen))
+        goto leave;
+
+      /* leave if we dropped in the same screen and there is only one
        * page in the notebook (window will close before we insert) */
       if (gtk_notebook_get_n_pages (GTK_NOTEBOOK (notebook)) < 2
           && *screen == widget)

-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the Xfce4-commits mailing list